JvmMethodBuilder

Struct JvmMethodBuilder 

pub struct JvmMethodBuilder { /* private fields */ }
JVM method builder

Implementations

Source

impl JvmMethodBuilder

pub fn new(name: String, descriptor: String) -> Self

Creates a new JVM method builder with the given name and descriptor

pub fn with_public(self) -> Self

Sets the method as public

pub fn with_private(self) -> Self

Sets the method as private

pub fn with_protected(self) -> Self

Sets the method as protected

pub fn with_static(self) -> Self

Sets the method as static

pub fn with_final(self) -> Self

Sets the method as final

pub fn with_synchronized(self) -> Self

Sets the method as synchronized

pub fn with_max_stack(self, max_stack: u16) -> Self

Sets the maximum stack size for the method

pub fn with_max_locals(self, max_locals: u16) -> Self

Sets the maximum number of local variables for the method

pub fn add_instruction(self, instruction: JvmInstruction) -> Self

Adds an instruction to the method

pub fn add_exception_handler(self, handler: JvmExceptionHandler) -> Self

Adds an exception handler to the method

pub fn add_exception(self, exception: impl Into<String>) -> Self

Adds a thrown exception to the method

pub fn nop(self) -> Self

Adds a NOP instruction

pub fn aconst_null(self) -> Self

Adds an ACONST_NULL instruction

pub fn iconst_m1(self) -> Self

Adds an ICONST_M1 instruction

pub fn iconst_0(self) -> Self

Adds an ICONST_0 instruction

pub fn iconst_1(self) -> Self

Adds an ICONST_1 instruction

pub fn iconst_2(self) -> Self

Adds an ICONST_2 instruction

pub fn iconst_3(self) -> Self

Adds an ICONST_3 instruction

pub fn iconst_4(self) -> Self

Adds an ICONST_4 instruction

pub fn iconst_5(self) -> Self

Adds an ICONST_5 instruction

pub fn lconst_0(self) -> Self

Adds an LCONST_0 instruction

pub fn lconst_1(self) -> Self

Adds an LCONST_1 instruction

pub fn fconst_0(self) -> Self

Adds an FCONST_0 instruction

pub fn fconst_1(self) -> Self

Adds an FCONST_1 instruction

pub fn fconst_2(self) -> Self

Adds an FCONST_2 instruction

pub fn dconst_0(self) -> Self

Adds a DCONST_0 instruction

pub fn dconst_1(self) -> Self

Adds a DCONST_1 instruction

pub fn bipush(self, value: i8) -> Self

Adds a BIPUSH instruction

pub fn sipush(self, value: i16) -> Self

Adds a SIPUSH instruction

pub fn ldc(self, symbol: impl Into<String>) -> Self

Adds an LDC instruction

pub fn iload(self, index: u16) -> Self

Adds an ILOAD instruction

pub fn lload(self, index: u16) -> Self

Adds an LLOAD instruction

pub fn fload(self, index: u16) -> Self

Adds an FLOAD instruction

pub fn dload(self, index: u16) -> Self

Adds a DLOAD instruction

pub fn aload(self, index: u16) -> Self

Adds an ALOAD instruction

pub fn iload_0(self) -> Self

Adds an ILOAD_0 instruction

pub fn iload_1(self) -> Self

Adds an ILOAD_1 instruction

pub fn iload_2(self) -> Self

Adds an ILOAD_2 instruction

pub fn iload_3(self) -> Self

Adds an ILOAD_3 instruction

pub fn lload_0(self) -> Self

Adds an LLOAD_0 instruction

pub fn lload_1(self) -> Self

Adds an LLOAD_1 instruction

pub fn lload_2(self) -> Self

Adds an LLOAD_2 instruction

pub fn lload_3(self) -> Self

Adds an LLOAD_3 instruction

pub fn fload_0(self) -> Self

Adds an FLOAD_0 instruction

pub fn fload_1(self) -> Self

Adds an FLOAD_1 instruction

pub fn fload_2(self) -> Self

Adds an FLOAD_2 instruction

pub fn fload_3(self) -> Self

Adds an FLOAD_3 instruction

pub fn dload_0(self) -> Self

Adds a DLOAD_0 instruction

pub fn dload_1(self) -> Self

Adds a DLOAD_1 instruction

pub fn dload_2(self) -> Self

Adds a DLOAD_2 instruction

pub fn dload_3(self) -> Self

Adds a DLOAD_3 instruction

pub fn aload_0(self) -> Self

Adds an ALOAD_0 instruction

pub fn aload_1(self) -> Self

Adds an ALOAD_1 instruction

pub fn aload_2(self) -> Self

Adds an ALOAD_2 instruction

pub fn aload_3(self) -> Self

Adds an ALOAD_3 instruction

pub fn istore(self, index: u16) -> Self

Adds an ISTORE instruction

pub fn lstore(self, index: u16) -> Self

Adds an LSTORE instruction

pub fn fstore(self, index: u16) -> Self

Adds an FSTORE instruction

pub fn dstore(self, index: u16) -> Self

Adds a DSTORE instruction

pub fn astore(self, index: u16) -> Self

Adds an ASTORE instruction

pub fn istore_0(self) -> Self

Adds an ISTORE_0 instruction

pub fn istore_1(self) -> Self

Adds an ISTORE_1 instruction

pub fn istore_2(self) -> Self

Adds an ISTORE_2 instruction

pub fn istore_3(self) -> Self

Adds an ISTORE_3 instruction

pub fn lstore_0(self) -> Self

Adds an LSTORE_0 instruction

pub fn lstore_1(self) -> Self

Adds an LSTORE_1 instruction

pub fn lstore_2(self) -> Self

Adds an LSTORE_2 instruction

pub fn lstore_3(self) -> Self

Adds an LSTORE_3 instruction

pub fn fstore_0(self) -> Self

Adds an FSTORE_0 instruction

pub fn fstore_1(self) -> Self

Adds an FSTORE_1 instruction

pub fn fstore_2(self) -> Self

Adds an FSTORE_2 instruction

pub fn fstore_3(self) -> Self

Adds an FSTORE_3 instruction

pub fn dstore_0(self) -> Self

Adds a DSTORE_0 instruction

pub fn dstore_1(self) -> Self

Adds a DSTORE_1 instruction

pub fn dstore_2(self) -> Self

Adds a DSTORE_2 instruction

pub fn dstore_3(self) -> Self

Adds a DSTORE_3 instruction

pub fn astore_0(self) -> Self

Adds an ASTORE_0 instruction

pub fn astore_1(self) -> Self

Adds an ASTORE_1 instruction

pub fn astore_2(self) -> Self

Adds an ASTORE_2 instruction

pub fn astore_3(self) -> Self

Adds an ASTORE_3 instruction

pub fn iadd(self) -> Self

Adds an IADD instruction

pub fn ladd(self) -> Self

Adds an LADD instruction

pub fn fadd(self) -> Self

Adds an FADD instruction

pub fn dadd(self) -> Self

Adds a DADD instruction

pub fn isub(self) -> Self

Adds an ISUB instruction

pub fn lsub(self) -> Self

Adds an LSUB instruction

pub fn fsub(self) -> Self

Adds an FSUB instruction

pub fn dsub(self) -> Self

Adds a DSUB instruction

pub fn imul(self) -> Self

Adds an IMUL instruction

pub fn lmul(self) -> Self

Adds an LMUL instruction

pub fn fmul(self) -> Self

Adds an FMUL instruction

pub fn dmul(self) -> Self

Adds a DMUL instruction

pub fn idiv(self) -> Self

Adds an IDIV instruction

pub fn ldiv(self) -> Self

Adds an LDIV instruction

pub fn fdiv(self) -> Self

Adds an FDIV instruction

pub fn ddiv(self) -> Self

Adds a DDIV instruction

pub fn irem(self) -> Self

Adds an IREM instruction

pub fn lrem(self) -> Self

Adds an LREM instruction

pub fn frem(self) -> Self

Adds an FREM instruction

pub fn drem(self) -> Self

Adds a DREM instruction

pub fn ineg(self) -> Self

Adds an INEG instruction

pub fn lneg(self) -> Self

Adds an LNEG instruction

pub fn fneg(self) -> Self

Adds an FNEG instruction

pub fn dneg(self) -> Self

Adds a DNEG instruction

pub fn ishl(self) -> Self

Adds an ISHL instruction

pub fn lshl(self) -> Self

Adds an LSHL instruction

pub fn ishr(self) -> Self

Adds an ISHR instruction

pub fn lshr(self) -> Self

Adds an LSHR instruction

pub fn iushr(self) -> Self

Adds an IUSHR instruction

pub fn lushr(self) -> Self

Adds an LUSHR instruction

pub fn iand(self) -> Self

Adds an IAND instruction

pub fn land(self) -> Self

Adds a LAND instruction

pub fn ior(self) -> Self

Adds an IOR instruction

pub fn lor(self) -> Self

Adds a LOR instruction

pub fn ixor(self) -> Self

Adds an IXOR instruction

pub fn lxor(self) -> Self

Adds an LXOR instruction

pub fn lcmp(self) -> Self

Adds an LCMP instruction

pub fn fcmpl(self) -> Self

Adds an FCMPL instruction

pub fn fcmpg(self) -> Self

Adds an FCMPG instruction

pub fn dcmpl(self) -> Self

Adds a DCMPL instruction

pub fn dcmpg(self) -> Self

Adds a DCMPG instruction

pub fn iinc(self, index: u16, value: i16) -> Self

Adds an IINC instruction

pub fn getstatic( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds a GETSTATIC instruction

pub fn putstatic( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds a PUTSTATIC instruction

pub fn getfield( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds a GETFIELD instruction

pub fn putfield( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds a PUTFIELD instruction

pub fn invokevirtual( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds an INVOKEVIRTUAL instruction

pub fn invokespecial( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds an INVOKESPECIAL instruction

pub fn invokestatic( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds an INVOKESTATIC instruction

pub fn invokeinterface( self, class: impl Into<String>, name: impl Into<String>, desc: impl Into<String>, ) -> Self

Adds an INVOKEINTERFACE instruction

pub fn new_instance(self, class: impl Into<String>) -> Self

Adds a NEW instruction

pub fn dup(self) -> Self

Adds a DUP instruction

pub fn dup_x1(self) -> Self

Adds a DUP_X1 instruction

pub fn dup_x2(self) -> Self

Adds a DUP_X2 instruction

pub fn dup2(self) -> Self

Adds a DUP2 instruction

pub fn dup2_x1(self) -> Self

Adds a DUP2_X1 instruction

pub fn dup2_x2(self) -> Self

Adds a DUP2_X2 instruction

pub fn swap(self) -> Self

Adds a SWAP instruction

pub fn pop(self) -> Self

Adds a POP instruction

pub fn pop2(self) -> Self

Adds a POP2 instruction

pub fn return_void(self) -> Self

Adds a RETURN instruction

pub fn ireturn(self) -> Self

Adds an IRETURN instruction

pub fn lreturn(self) -> Self

Adds an LRETURN instruction

pub fn freturn(self) -> Self

Adds an FRETURN instruction

pub fn dreturn(self) -> Self

Adds a DRETURN instruction

pub fn areturn(self) -> Self

Adds an ARETURN instruction

pub fn label(self, name: impl Into<String>) -> Self

Adds a label instruction

pub fn goto(self, target: impl Into<String>) -> Self

Adds a GOTO instruction

pub fn ifeq(self, target: impl Into<String>) -> Self

Adds an IFEQ instruction

pub fn ifne(self, target: impl Into<String>) -> Self

Adds an IFNE instruction

pub fn build(self) -> JvmMethod

Builds and returns the JVM method