ClassWriter

Struct ClassWriter 

pub struct ClassWriter<W: Write> { /* private fields */ }
JVM Class file writer

Implementations

Source

impl<W: Write> ClassWriter<W>

pub fn collect_attribute_constants(&mut self, attribute: &JvmAttribute)

Collects constants from an attribute and adds them to the constant pool

pub fn collect_annotation_constants(&mut self, annotations: &[JvmAnnotation])

Collects constants from annotations

pub fn collect_annotation_value_constants(&mut self, value: &JvmAnnotationValue)

Collects constants from annotation values

pub fn collect_verification_type_constants(&mut self, vt: &JvmVerificationType)

Collects constants from a verification type and adds them to the constant pool

pub fn write_attribute(&mut self, attribute: &JvmAttribute) -> Result<()>

Writes an attribute to the class file

pub fn write_verification_type_to_buf( &mut self, vt: &JvmVerificationType, buf: &mut Vec<u8>, ) -> Result<()>

Writes a verification type to a buffer

pub fn write_stack_map_frame_to_buf( &mut self, frame: &JvmStackMapFrame, buf: &mut Vec<u8>, ) -> Result<()>

Writes a stack map frame to a buffer

pub fn write_annotation_to_buf( &mut self, annotation: &JvmAnnotation, buf: &mut Vec<u8>, ) -> Result<()>

Writes an annotation to a buffer

pub fn write_annotation_element_to_buf( &mut self, element: &JvmAnnotationElement, buf: &mut Vec<u8>, ) -> Result<()>

Writes an annotation element to a buffer

pub fn write_annotation_value_to_buf( &mut self, value: &JvmAnnotationValue, buf: &mut Vec<u8>, ) -> Result<()>

Writes an annotation value to a buffer

pub fn write_code_attribute( &mut self, program: &JvmProgram, method: &JvmMethod, code_utf8_idx: u16, ) -> Result<()>

Writes a Code attribute to the class file

Source

impl<W: Write> ClassWriter<W>

pub fn write_fields(&mut self, program: &JvmProgram) -> Result<()>

写入字段

pub fn write_methods( &mut self, program: &JvmProgram, code_utf8_idx: u16, ) -> Result<()>

写入方法

Source

impl<W: Write> ClassWriter<W>

pub fn generate_method_bytecode( &mut self, method: &JvmMethod, ) -> (Vec<u8>, HashMap<String, i32>)

生成方法的字节码及标签位置

pub fn emit_instruction( &mut self, instruction: &JvmInstruction, bytecode: &mut Vec<u8>, jump_patches: &mut Vec<(usize, usize, String, bool)>, pos: usize, )

发射单条指令的字节码

Source

impl<W: Write> ClassWriter<W>

pub fn add_utf8(&mut self, s: String) -> u16

Adds a Utf8 constant to the constant pool

pub fn add_class(&mut self, name: String) -> u16

Adds a Class constant to the constant pool

pub fn add_string(&mut self, value: String) -> u16

Adds a String constant to the constant pool

pub fn add_name_and_type(&mut self, name: String, descriptor: String) -> u16

Adds a NameAndType constant to the constant pool

pub fn add_field_ref( &mut self, class_name: String, name: String, descriptor: String, ) -> u16

Adds a Fieldref constant to the constant pool

pub fn add_method_ref( &mut self, class_name: String, name: String, descriptor: String, ) -> u16

Adds a Methodref constant to the constant pool

pub fn add_interface_method_ref( &mut self, class_name: String, name: String, descriptor: String, ) -> u16

Adds an InterfaceMethodref constant to the constant pool

pub fn add_int(&mut self, val: i32) -> u16

Adds an Integer constant to the constant pool

pub fn add_float(&mut self, val: f32) -> u16

Adds a Float constant to the constant pool

pub fn add_long(&mut self, val: i64) -> u16

Adds a Long constant to the constant pool

pub fn add_double(&mut self, val: f64) -> u16

Adds a Double constant to the constant pool

pub fn add_method_handle(&mut self, kind: u8, ref_idx: u16) -> u16

Adds a MethodHandle constant to the constant pool

pub fn add_method_type(&mut self, descriptor: String) -> u16

Adds a MethodType constant to the constant pool

pub fn add_dynamic( &mut self, bootstrap_method_attr_idx: u16, name: String, descriptor: String, ) -> u16

Adds a Dynamic constant to the constant pool

pub fn add_invoke_dynamic( &mut self, bootstrap_method_attr_idx: u16, name: String, descriptor: String, ) -> u16

Adds an InvokeDynamic constant to the constant pool

pub fn add_module(&mut self, name: String) -> u16

Adds a Module constant to the constant pool

pub fn add_package(&mut self, name: String) -> u16

Adds a Package constant to the constant pool

pub fn add_cp_entry(&mut self, entry: CpEntry) -> u16

Adds a constant pool entry and returns its index

pub fn write_constant_pool(&mut self) -> Result<()>

Writes the constant pool to the class file

Source

impl<W: Write> ClassWriter<W>

pub fn new(writer: W) -> Self

Create a new Class writer

pub fn finish(self) -> W

Finish writing and return the underlying writer

pub fn write(self, program: &JvmProgram) -> GaiaDiagnostics<W>

Write ClassView as binary Class format