Main Program Module
This module is the main entry point of the JVM assembler, responsible for coordinating various components (such as the lexer, parser, and writer) to complete the conversion from JASM assembly code to JVM bytecode.
Main Features
- Command Line Interface (CLI): Handles command-line arguments and configures program behavior.
- File I/O: Reads JASM assembly files and writes generated
.classfiles. - Flow Control: Orchestrates the entire flow of lexical analysis, parsing, and writing.
- Error Reporting: Collects and reports errors and warnings that occur throughout the compilation process.
Structure
run_app: The program’s main function, containing command-line parsing and main logic.config: Program configuration, such as input/output file paths, compilation options, etc.
Usage Example
Re-exports
pub use JvmConstantPoolEntry as ConstantPoolEntry;
Modules
- opcodes
- 操作码常量模块
Structs
- JvmAccess
Flags - JVM 访问标志
- JvmClass
Compat - 向后兼容的 JvmClass 结构
- JvmConstant
Pool - JVM 常量池(高层表示)
- JvmException
Handler - JVM 异常处理表项(高层表示)
- JvmField
- JVM 字段信息(高层表示)
- JvmField
Compat - 向后兼容的 JvmField 结构
- JvmInner
Class - JVM 内部类信息
- JvmInstruction
Compat - 向后兼容的 JvmInstruction 结构
- JvmLocal
Variable - JVM 局部变量信息
- JvmMethod
- JVM 方法信息(高层表示)
- JvmMethod
Compat - 向后兼容的 JvmMethod 结构
- JvmProgram
- JVM 程序的高层次表示
- JvmVersion
- JVM 版本信息
- RawException
Handler - JVM 异常处理表项(二进制表示)
Enums
- JvmAttribute
- JVM 属性
- JvmConstant
Pool Entry - JVM 常量池条目(高层表示)
- JvmInstruction
- JVM 指令(高层表示)
- JvmStack
MapFrame - JVM StackMapTable 帧
- JvmVerification
Type - JVM 验证类型